// =========================================================
// BMPCTL.CPP
//
// Bitmap Control for OWL 2
// - used to place bitmaps in a dialog box
//
// Author:  Steve Saxon (Compuserve: 100321,2355)
// Written: 15th October 1994
// =========================================================
// Copyright 1994 by Steve Saxon

#include "owlxpch.hpp"
#pragma hdrstop

// =========================================================
// TBitmapControl
//
// bitmap control - assumes a placeholder exists in the
// dialog template (eg. a blackrect static control)
// =========================================================

TBitmapControl::TBitmapControl (TWindow* parent, int resourceID, Style _style, TModule* module)
	: TControl (parent, resourceID, module)
{
	style 	= _style;
	bitmap 	= new TBitmap (GetModule ()->GetInstance (), resourceID);
} // End of TBitmapControl

TBitmapControl::TBitmapControl (TWindow* parent, int resourceID , TBitmap * bm , Style _style, TModule* module)
	: TControl (parent, resourceID, module) ,
    bitmap ( bm )
{
	style 	= _style;
} // End of TBitmapControl CTOR

TBitmapControl::~TBitmapControl ( void )
{
	delete bitmap;
} // End of TBitmapControl DTOR

void TBitmapControl::SetupWindow ( void )
{
	TControl::SetupWindow ();

	ClearFlag (wfPredefinedClass);

    if (NULL != bitmap)
    {
        BITMAP		bm;
        bitmap->GetObject (bm);
        bmRect.Set(0, 0, bm.bmWidth, bm.bmHeight);
    }
} // End of SetupWindow


void TBitmapControl::Paint (TDC& dc, BOOL, TRect&)
{
    TRect client;
    GetClientRect( client );
	int			nMargin;

	switch (style)
	{
		case Plain :
		{
			nMargin = 1;
			break;
		}
		case Recessed :
		case Raised :
		{
			nMargin = 2;
			break;
		}
		default :
		{
			nMargin = 0;
			break;
		}
	}

	if (nMargin)
	{
		client.right 	+= (nMargin << 1);
		client.bottom 	+= (nMargin << 1);
	}

	switch (style)
	{
		case Plain :
		{
			dc.FrameRect (client, TBrush (GetSysColor (COLOR_WINDOWFRAME)));
			client = client.InflatedBy (-1, -1);
			break;
		}
		case Recessed :
		case Raised :
		{
			TPen	penShadow (GetSysColor (COLOR_BTNSHADOW));
			TPen	penHilite (GetSysColor (COLOR_BTNHIGHLIGHT));
			TPen	penGrey (GetSysColor (COLOR_BTNFACE));
			TPen	penBlack (GetSysColor (COLOR_WINDOWFRAME));

			dc.SelectObject (penShadow);
			dc.MoveTo (client.right - 1, client.top);
			dc.LineTo (client.left, client.top);
			dc.LineTo (client.left, client.bottom - 1);
			dc.SelectObject (penHilite);
			dc.LineTo (client.right - 1, client.bottom - 1);
			dc.LineTo (client.right - 1, client.top - 1);
			client = client.InflatedBy (-1, -1);

			dc.SelectObject (penBlack);
			dc.MoveTo (client.right - 1, client.top);
			dc.LineTo (client.left, client.top);
			dc.LineTo (client.left, client.bottom - 1);
			dc.SelectObject (penGrey);
			dc.LineTo (client.right - 1, client.bottom - 1);
			dc.LineTo (client.right - 1, client.top - 1);
			client = client.InflatedBy (-1, -1);

			//
			// select stock objects back into the DC
			//
			dc.SelectStockObject (BLACK_PEN);
			break;
		}
	}

    paintBitmap( dc , client );
}

void TBitmapControl::paintBitmap ( TDC & dc , TRect & client )
{
	TMemoryDC	dcMem (dc);
	dcMem.SelectObject (*bitmap);

    dc.StretchBlt( client , dcMem , bmRect );
//	dc.BitBlt (client, dcMem, TPoint (0, 0));

} // End of PaintBitmap



