// *------------------------------------------------------------------------*
// |                                                                        |
// | TDIBCTL.CPP                                                            |
// |                                                                        |
// | This module implements a control for painting DIBs                     |
// |                                                                        |
// | Stuart Booth                                                           |
// |                                                                        |
// | Dependant Modules                                                      |
// | ~~~~~~~~~~~~~~~~~                                                      |
// | BMPCTL.CPP from PropertyDialogs                                        |
// |                                                                        |
// | Change History                                                         |
// | ~~~~~~~~~~~~~~                                                         |
// | First created. Based on Steve Saxon's TBitmapControl control           |
// |  o 28th October 1995                                                   |
// |                                                                        |
// | Known Bug List                                                         |
// | ~~~~~~~~~~~~~~                                                         |
// |                                                                        |
// | Notes                                                                  |
// | ~~~~~                                                                  |
// |                                                                        |
// *------------------------------------------------------------------------*


// --------------------------------------------------------------------------
// Includes
// --------------------------------------------------------------------------

#include "owlxpch.hpp"

#pragma hdrstop

#include "tdibctl.hpp"


// --------------------------------------------------------------------------
// Defines
// --------------------------------------------------------------------------


// --------------------------------------------------------------------------
// Global Variables
// --------------------------------------------------------------------------


// --------------------------------------------------------------------------
// Other Definitions
// --------------------------------------------------------------------------


// +------------------------------------------------------------------------+
// | TDIBCONTROL CTOR                                                       |
// | Function: Initialises the DIB control using the same resource ID for   |
// |           the window element ID and the resource based image to load.  |
// | Params:   TWindow * parent - parent window                             |
// |           int resourceID - id to link TControl object to and DIB       |
// |                            resource to load from this module           |
// |           Style _style - edge style. See TBitmapControl                |
// |           TModule * module - uhhh                                      |
// | Returns:  N/A                                                          |
// +------------------------------------------------------------------------+

TDIBControl::TDIBControl (TWindow* parent, int resourceID, Style _style, TModule* module)
	: TBitmapControl (parent, resourceID, NULL , _style , module)
{
	dib 	= new TDib (GetModule ()->GetInstance (), resourceID);

}


// +------------------------------------------------------------------------+
// | TDIBCONTROL CTOR                                                       |
// | Function: Initialises the DIB contronl using the a specified/precreated|
// |           DIB                                                          |
// | Params:   TWindow * parent - parent window                             |
// |           int resourceID - id to link TControl object to               |
// |           TDib * _dib - dib to use. We now own this object and deleteit|
// |           Style _style - edge style. See TBitmapControl                |
// |           TModule * module - uhhh                                      |
// | Returns:  N/A                                                          |
// +------------------------------------------------------------------------+

TDIBControl::TDIBControl (TWindow* parent, int resourceID , TDib * _dib, Style _style, TModule* module)
	: TBitmapControl (parent, resourceID, NULL , _style , module) ,
    dib ( _dib )
{
} // End of TDIBControl CTOR


// +------------------------------------------------------------------------+
// | TDIBCONTROL DTOR                                                       |
// | Function: Deletes the DIB and palette from memory                      |
// | Params:   void                                                         |
// | Returns:  N/A                                                          |
// +------------------------------------------------------------------------+

TDIBControl::~TDIBControl ( void )
{
	delete dib;
    delete palette;
} // End of TDIBControl


// +------------------------------------------------------------------------+
// | SETUPWINDOW                                                            |
// | Function: Takes the DIB and creates a Bitmap and Palette from it for   |
// |           use during painting.                                         |
// | Params:   void                                                         |
// | Returns:  void                                                         |
// +------------------------------------------------------------------------+

void TDIBControl::SetupWindow ( void )
{
    palette = new TPalette ( *dib );
    bitmap = new TBitmap ( *dib );

	TBitmapControl::SetupWindow ();

} // End of SetupWindow


// +------------------------------------------------------------------------+
// | PAINTBITMAP                                                            |
// | Function: Does the actual bitmap painting.                             |
// | Params:   void                                                         |
// | Returns:  void                                                         |
// +------------------------------------------------------------------------+

void TDIBControl::paintBitmap (TDC& dc, TRect& client )
{
	TMemoryDC	dcMem (dc);

	dcMem.SelectObject(*bitmap);
    dcMem.SelectObject(*palette);
    dc.SelectObject( *palette , true );
    dc.RealizePalette();

    dc.StretchBlt( client , dcMem , bmRect );
//	dc.BitBlt (client, dcMem, TPoint (0, 0));

    dcMem.RestorePalette();
    dc.RestorePalette();
    dc.RealizePalette();
    dcMem.RestoreObjects();

} // End of PaintBitmap


